<?php
/**
 * Plugin Name: Catch Updater
 * Plugin URI: https://catchthemes.com/plugins/catch-updater/
 * Description: Catch Updater is a simple and lightweight WordPress Theme Updater Plugin, which enables you to update your themes easily using WordPress Admin Panel. Now, you can simple upload your Pro/Premium theme new version zip file from Theme Installer "Appearance => Themes => Add New => Upload". You also get an option to backup your existing theme while updating to latest version. No more hassle of deleting the theme and uploading new one.
 * Author: Catch Themes Team
 * Author URI:  https://catchthemes.com
 * Version: 1.6.2
 * License: GNU General Public License, version 3 (GPLv3)
 * License URI: http://www.gnu.org/licenses/gpl-3.0.txt
 * Requires at least: 4.5
 * Tested up to: 4.9.4
 *
 * Text Domain: catch-updater
 * Domain Path: /catch-updater/
 *
 * @package Catch Updater
 * @subpackage Catch Updater
 * @author CatchThemes
 * @since Catch Updater 0.1
 */


// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Define Version
define( 'CATCHUPDATER_VERSION', '1.6.1' );


// The URL of the directory that contains the plugin
if ( !defined( 'CATCHUPDATER_URL' ) )
	define( 'CATCHUPDATER_URL', plugin_dir_url( __FILE__ ) );


// The absolute path of the directory that contains the file
if ( !defined( 'CATCHUPDATER_PATH' ) )
	define( 'CATCHUPDATER_PATH', plugin_dir_path( __FILE__ ) );


// Gets the path to a plugin file or directory, relative to the plugins directory, without the leading and trailing slashes.
if ( !defined( 'CATCHUPDATER_BASENAME' ) )
	define( 'CATCHUPDATER_BASENAME', plugin_basename( __FILE__ ) );

/**
 * Make plugin available for translation
 * Translations can be filed in the /languages/ directory
 */
function catch_updater_load_textdomain() {
	load_plugin_textdomain( 'catch-updater', false, basename( dirname( __FILE__ ) ) . '/languages' );
}
add_filter( 'wp_loaded', 'catch_updater_load_textdomain' );


/**
 * Compare PHP Version
 *
 * Activate only if PHP version 4 or above
 */
if ( version_compare( PHP_VERSION, '3.5', '<' ) ) {
	if ( is_admin() && ( !defined( 'DOING_AJAX' ) || !DOING_AJAX ) ) {
		require_once ABSPATH . '/wp-admin/includes/plugin.php';

		deactivate_plugins( __FILE__ );

		wp_die( sprintf( __( 'Catch Updater requires PHP 5 or higher, as does WordPress 3.5 and higher. The plugin has now disabled itself.', 'catch-updater' ) ) );
	} else {
		return;
	}
}

if ( is_admin() ){
	require_once CATCHUPDATER_PATH . 'inc/catch-updater-modify-installer.php';

	require_once CATCHUPDATER_PATH . 'inc/catch-updater-plugin-modify-installer.php';

	add_filter( 'plugin_action_links', 'catch_updater_action_links', 10, 2 );
	function catch_updater_action_links( $links, $plugin_file  ) {
		if ( !isset( $plugin ) ) {
			$plugin = plugin_basename(__FILE__);
		}

		if ( $plugin == $plugin_file ) {
			$customizer_link = admin_url( 'theme-install.php?upload' );

			$settings_link   = '<a href="' . esc_url( $customizer_link ) . '">' .esc_html__( 'Upload Theme', 'catch-updater' ) . '</a>';

			array_unshift( $links, $settings_link );

			$customizer_link = admin_url( 'plugin-install.php?upload' );

			$settings_link   = '<a href="' . esc_url( $customizer_link ) . '">' .esc_html__( 'Upload Plugin', 'catch-updater' ) . '</a>';

			array_unshift( $links, $settings_link );
		}

		return $links;
	}
}
else
	require_once CATCHUPDATER_PATH . 'inc/catch-updater-show-maintenance-message.php';

require_once 'inc/catch-updater-plugin-update-checker.php';

$CatchUpdateChecker = CatchUpdaterPucFactory::buildUpdateChecker(
    'https://catchthemes.com/update-notifier/catch-updater/catch_updater_meta_data.json',
    __FILE__,
    'catch-updater'
);
